@@ -36,12 +36,15 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Element };
 
+use Carp;
 use List::Util qw{ max };
-use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
+use PPIx::Regexp::Constant qw{ MINIMUM_PERL NODE_UNKNOWN };
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.041';
+our $VERSION = '0.048';
+
+use constant ELEMENT_UNKNOWN	=> NODE_UNKNOWN;
 
 sub _new {
     my ( $class, @children ) = @_;
@@ -288,7 +291,8 @@ supported by this package.
 
 sub perl_version_introduced {
     my ( $self ) = @_;
-    return max( MINIMUM_PERL,
+    return max( grep { defined $_ } MINIMUM_PERL,
+	$self->{perl_version_introduced},
 	map { $_->perl_version_introduced() } $self->elements() );
 }
 
@@ -403,14 +407,27 @@ sub _nav {
     return ( $method => [ $inx ] );
 }
 
+sub __error {
+    my ( $self, $msg, %arg ) = @_;
+    defined $msg
+	or $msg = 'Was class ' . ref $self;
+    $self->{error} = $msg;
+    bless $self, $self->ELEMENT_UNKNOWN();
+    foreach my $key ( keys %arg ) {
+	$self->{$key} = $arg{$key};
+    }
+    return 1;
+}
+
+
 # Called by the lexer once it has done its worst to all the tokens.
-# Called as a method with no arguments. The return is the number of
-# parse failures discovered when finalizing.
+# Called as a method with the lexer as argument. The return is the
+# number of parse failures discovered when finalizing.
 sub __PPIX_LEXER__finalize {
-    my ( $self ) = @_;
+    my ( $self, $lexer ) = @_;
     my $rslt = 0;
     foreach my $elem ( $self->elements() ) {
-	$rslt += $elem->__PPIX_LEXER__finalize();
+	$rslt += $elem->__PPIX_LEXER__finalize( $lexer );
     }
     return $rslt;
 }
@@ -439,7 +456,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2015 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
