@@ -41,7 +41,13 @@ use Carp;
 
 use base qw{ PPIx::Regexp::Structure::Capture };
 
-our $VERSION = '0.020';
+our $VERSION = '0.048';
+
+sub explain {
+    my ( $self ) = @_;
+    return sprintf q<Named capture group '%s' (number %d)>,
+	$self->name(), $self->number();
+}
 
 =head2 name
 
@@ -73,7 +79,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
