@@ -35,13 +35,31 @@ use warnings;
 use base qw{ PPIx::Regexp::Token::Reference };
 
 use Carp qw{ confess };
-use PPIx::Regexp::Constant qw{ MINIMUM_PERL RE_CAPTURE_NAME };
+use PPIx::Regexp::Constant qw{
+    MINIMUM_PERL RE_CAPTURE_NAME
+    TOKEN_LITERAL TOKEN_UNKNOWN
+};
+use PPIx::Regexp::Util qw{ __to_ordinal_en };
 
-our $VERSION = '0.034';
+our $VERSION = '0.048';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+sub explain {
+    my ( $self ) = @_;
+    $self->is_named()
+	and return sprintf q<Back reference to capture group '%s'>,
+	    $self->name();
+    $self->is_relative()
+	and return sprintf
+	    q<Back reference to %s previous capture group (%d in this regexp)>,
+	    __to_ordinal_en( - $self->number() ),
+	    $self->absolute();
+    return sprintf q<Back reference to capture group %d>,
+	$self->absolute();
+}
+
 {
 
     my %perl_version_introduced = (
@@ -64,7 +82,7 @@ my @external = (	# Recognition used externally
 	],
 );
 
-my @recognize = (	# recognition used internally
+my @recognize_regexp = (	# recognition used internally
     [
 	qr{ \A \\ (?:		# numbered (including relative)
 	    ( \d+ )	|
@@ -80,6 +98,13 @@ my @recognize = (	# recognition used internally
 	}smxo, { is_named => 1 }, ],
 );
 
+my %recognize = (
+    regexp	=> \@recognize_regexp,
+    repl	=> [
+	[ qr{ \A \\ ( \d+ ) }smx, { is_named => 0 } ],
+    ],
+);
+
 # This must be implemented by tokens which do not recognize themselves.
 # The return is a list of list references. Each list reference must
 # contain a regular expression that recognizes the token, and optionally
@@ -88,12 +113,12 @@ my @recognize = (	# recognition used internally
 # the string.
 sub __PPIX_TOKEN__recognize {
     return __PACKAGE__->isa( scalar caller ) ?
-	( @external, @recognize ) :
+	( @external, @recognize_regexp ) :
 	( @external );
 }
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     # PCRE/Python back references are handled in
     # PPIx::Regexp::Token::Structure, because they are parenthesized.
@@ -102,21 +127,72 @@ sub __PPIX_TOKENIZER__regexp {
     $character eq '\\'
 	or return;
 
-    foreach ( @recognize ) {
+    foreach ( @{ $recognize{$tokenizer->get_mode()} } ) {
 	my ( $re, $arg ) = @{ $_ };
 	my $accept = $tokenizer->find_regexp( $re ) or next;
-	return $tokenizer->make_token( $accept, __PACKAGE__, $arg );
+	my %arg = ( %{ $arg }, tokenizer => $tokenizer );
+	return $tokenizer->make_token( $accept, __PACKAGE__, \%arg );
     }
 
     return;
 }
 
 sub __PPIX_TOKENIZER__repl {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer ) = @_;	# Invocant, $character unused
 
-    $tokenizer->interpolates() and goto &__PPIX_TOKENIZER__regexp;
+    $tokenizer->interpolates()
+	or return;
 
-    return;
+    goto &__PPIX_TOKENIZER__regexp;
+}
+
+# Called by the lexer to disambiguate between captures, literals, and
+# whatever. We have to return the number of tokens reblessed to
+# TOKEN_UNKNOWN (i.e. either 0 or 1) because we get called after the
+# parse is finalized.
+sub __PPIX_LEXER__rebless {
+    my ( $self, %arg ) = @_;
+
+    # Handle named back references
+    if ( $self->is_named() ) {
+	$arg{capture_name}{$self->name()}
+	    and return 0;
+	return $self->__error();
+    }
+
+    # Get the absolute capture group number.
+    my $absolute = $self->absolute();
+
+    # If it is zero or negative, we have a relateive reference to a
+    # non-existent capture group.
+    $absolute <= 0
+	and return $self->__error();
+
+    # If the absolute number is less than or equal to the maximum
+    # capture group number, we are good.
+    $absolute <= $arg{max_capture}
+	and return 0;
+
+    # It's not a valid capture. If it's an octal literal, rebless it so.
+    # Note that we can't rebless single-digit numbers, since they can't
+    # be octal literals.
+    my $content = $self->content();
+    if ( $content =~ m/ \A \\ [0-7]{2,} \z /smx ) {
+	bless $self, TOKEN_LITERAL;
+	return 0;
+    }
+
+    # Anything else is an error.
+    return $self->__error();
+}
+
+sub __error {
+    my ( $self, $msg ) = @_;
+    defined $msg
+	or $msg = 'No corresponding capture group';
+    $self->{error} = $msg;
+    bless $self, TOKEN_UNKNOWN;
+    return 1;
 }
 
 1;
@@ -134,7 +210,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2013 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
