@@ -35,11 +35,15 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::Structure };
 
-our $VERSION = '0.034';
+our $VERSION = '0.048';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+sub explain {
+    return 'Regular expression or replacement string delimiter';
+}
+
 1;
 
 __END__
@@ -55,7 +59,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2013 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
