@@ -37,11 +37,24 @@ use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.034';
+our $VERSION = '0.048';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
 
+{
+
+    my %explanation = (
+	'+'	=> 'match longest string and give nothing back',
+	'?'	=> 'match shortest string first',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+}
+
 my %greediness = (
     '?' => MINIMUM_PERL,
     '+' => '5.009005',
@@ -57,7 +70,7 @@ indicator; that is, if it is '+' or '?'.
 =cut
 
 sub could_be_greediness {
-    my ( $class, $string ) = @_;
+    my ( undef, $string ) = @_;		# Invocant unused
     return $greediness{$string};
 }
 
@@ -67,9 +80,10 @@ sub perl_version_introduced {
 }
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character, $char_type ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;	# Invocant, $char_type unused
 
-    $tokenizer->prior( 'is_quantifier' ) or return;
+    $tokenizer->prior_significant_token( 'is_quantifier' )
+	or return;
 
     $greediness{$character} or return;
 
@@ -91,7 +105,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2013 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
