@@ -43,7 +43,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-our $VERSION = '0.041';
+our $VERSION = '0.048';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
@@ -66,7 +66,8 @@ the defining strings, inside a C<(?= ... )>, so that it is not included
 in the match.
 
 This method B<must> be overridden, unless C<__make_group_type_matcher()>
-is.
+is. The override B<must> return the same thing each time, since the
+results of C<__make_group_type_matcher()> are cached.
 
 =cut
 
@@ -108,10 +109,11 @@ sub __make_group_type_matcher {
 	qr/ (?= \Q$opt->{suffix}\E ) /smx :
 	'';
 
+    my %seen;
+    my @chars = grep { ! $seen{$_}++ } split qr{}smx, join '', @defs;
+
     my %rslt;
-    foreach my $str ( $class->__defining_string() ) {
-	my %seen;
-	my @chars = grep { ! $seen{$_}++ } split qr{}smx, $str;
+    foreach my $str ( @defs ) {
 	push @{ $rslt{''} ||= [] }, qr{ \A \Q$str\E $suffix }smx;
 	foreach my $chr ( @chars ) {
 	    ( my $expr = $str ) =~ s/ (?= \Q$chr\E ) /\\/smxg;
@@ -147,7 +149,7 @@ sub __match_setup {
 my %matcher;
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $class, $tokenizer ) = @_;	# $character unused
 
     my $mtch = $matcher{$class} ||= $class->__make_group_type_matcher();
 
@@ -179,7 +181,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2015 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
