@@ -38,7 +38,7 @@ use base qw{ PPIx::Regexp::Token::Modifier PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.020';
+our $VERSION = '0.048';
 
 {
 
@@ -48,7 +48,7 @@ our $VERSION = '0.020';
 
     sub perl_version_introduced {
 	my ( $self ) = @_;
-	my $content = $self->content();
+	my $content = $self->unescaped_content();
 	exists $perl_version_introduced{$content}
 	    and return $perl_version_introduced{$content};
 	my $ver = $self->SUPER::perl_version_introduced();
@@ -58,6 +58,8 @@ our $VERSION = '0.020';
 
 }
 
+=begin comment
+
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
@@ -77,6 +79,31 @@ sub __PPIX_TOKENIZER__regexp {
     return;
 }
 
+=end comment
+
+=cut
+
+sub __make_group_type_matcher {
+    return {
+	''	=> [
+	    qr{ \A [?] [[:lower:]]* -? [[:lower:]]* : }smx,
+	    qr{ \A [?] \^ [[:lower:]]* : }smx,
+	],
+	'?'	=> [
+	    qr{ \A \\ [?] [[:lower:]]* -? [[:lower:]]* : }smx,
+	    qr{ \A \\ [?] \^ [[:lower:]]* : }smx,
+	],
+	'-'	=> [
+	    qr{ \A [?] [[:lower:]]* (?: \\ - )? [[:lower:]]* : }smx,
+	    qr{ \A [?] \^ [[:lower:]]* : }smx,
+	],
+	':'	=> [
+	    qr{ \A [?] [[:lower:]]*  -? [[:lower:]]* \\ : }smx,
+	    qr{ \A [?] \^ [[:lower:]]* \\ : }smx,
+	],
+    };
+}
+
 1;
 
 __END__
@@ -92,7 +119,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
