@@ -35,14 +35,72 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-use PPIx::Regexp::Constant qw{ TOKEN_LITERAL };
+use PPIx::Regexp::Constant qw{
+    COOKIE_CLASS COOKIE_REGEX_SET
+    TOKEN_LITERAL
+};
 use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.041';
+our $VERSION = '0.048';
+
+use constant TOKENIZER_ARGUMENT_REQUIRED => 1;
+
+sub __new {
+    my ( $class, $content, %arg ) = @_;
+
+    my $self = $class->SUPER::__new( $content, %arg )
+	or return;
+
+    $self->{operation} = $self->_compute_operation_name(
+	$arg{tokenizer} ) || 'unknown';
+
+    return $self;
+}
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+sub explain {
+    my ( $self ) = @_;
+    my $expl = ucfirst "$self->{operation} operator";
+    $expl =~ s/ _ / /smxg;
+    return $expl;
+}
+
+=head2 operation
+
+This method returns the name of the operation performed by the operator.
+This depends not only on the operator itself but its context:
+
+=over
+
+=item In a bracketed character class
+
+    '-' => 'range',
+    '^' => 'inversion',
+
+=item In an extended bracketed character class
+
+    '&' => 'intersection',
+    '+' => 'union',
+    '|' => 'union',
+    '-' => 'subtraction',
+    '^' => 'symmetric_difference',
+    '!' => 'complement',
+
+=item Outside any sort of bracketed character class
+
+    '|' => 'alternation',
+
+=back
+
+=cut
+
+sub operation {
+    my ( $self ) = @_;
+    return $self->{operation};
+}
+
 # These will be intercepted by PPIx::Regexp::Token::Literal if they are
 # really literals, so here we may process them unconditionally.
 
@@ -57,8 +115,45 @@ sub _treat_as_literal {
 	__instance( $token, 'PPIx::Regexp::Token::Interpolation' );
 }
 
+{
+
+    my %operation = (
+	COOKIE_CLASS()	=> {
+	    '-'	=> 'range',
+	    '^'	=> 'inversion',
+	},
+	COOKIE_REGEX_SET()		=> {
+	    '&'	=> 'intersection',
+	    '+'	=> 'union',
+	    '|'	=> 'union',
+	    '-'	=> 'subtraction',
+	    '^'	=> 'symmetric_difference',
+	    '!'	=> 'complement',
+	},
+	''	=> {
+	    '|'	=> 'alternation',
+	},
+    );
+
+    sub _compute_operation_name {
+	my ( $self, $tokenizer ) = @_;
+
+	my $content = $self->content();
+
+	if ( $tokenizer->cookie( COOKIE_CLASS ) ) {
+	    return $operation{ COOKIE_CLASS() }{$content};
+	} elsif ( $tokenizer->cookie( COOKIE_REGEX_SET ) ) {
+	    return $operation{ COOKIE_REGEX_SET() }{$content};
+	} else {
+	    return $operation{''}{$content};
+	}
+    }
+
+
+}
+
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     # We only receive the '-' if we are inside a character class. But it
     # is only an operator if it is preceded and followed by literals. We
@@ -66,7 +161,7 @@ sub __PPIX_TOKENIZER__regexp {
     # character class.
     if ( $character eq '-' ) {
 
-	_treat_as_literal( $tokenizer->prior() )
+	_treat_as_literal( $tokenizer->prior_significant_token() )
 	    or return $tokenizer->make_token( 1, TOKEN_LITERAL );
 	
 	my @tokens = ( $tokenizer->make_token( 1 ) );
@@ -96,7 +191,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2015 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
